#!/bin/sh

TAR_FILE=/tmp/mtx-conf.tgz
FILES=""

# print usage
usage() {
cat <<UEOF
Usage: $0 [-r] [-f FILENAME.tgz] [-a] [-n] [-y] [-c] 

backup and restore the configuration files from /etc

Optional arguments:
  -h			display this
  -r			RESTORE
  -f FILENAME		file name (default: $TAR_FILE)
  -a 			backup all files in /etc
  -n			backup network configuration
  -y			backup files in /etc/nylon
  -c			backup certificates

without arguments all important files are backed up. 

if you want to install the backup on a new or different distribution version,
please back up as little files as possible (using the -nyc switches) because
configuration files or locations may have changed.

UEOF
exit
}

# options
while getopts "rf:anyc" options; do
	case $options in
		r ) RESTORE="Y";;
		f ) TAR_FILE=$OPTARG;;
		a ) DO_ALL="Y";;
		n ) DO_NET="Y";;
		y ) DO_NYLON="Y";;
		c ) DO_CERTS="Y";;
		* ) usage
	esac
done

if [ "$RESTORE" == "Y" ]; then 
	echo "* restoring configuration from $TAR_FILE..."
	echo
	echo "restoring configurations from older distribution versions can make the" 
	echo "system unusable - especially especially when you backed up all files!"
	echo
	# ask
	read -p "*** do you want to contine? (yes/no) " answer
	[[ $answer == "yes" ]] ||  exit 0;
	tar xvzf $TAR_FILE
else
	echo "* backup configuration to $TAR_FILE..."
	
	if [ "$DO_ALL" == "Y" ]; then
		echo "" > /tmp/exclude
		FILES="/etc"
	else	
		[ "$DO_NET" == "Y" ] && FILES="$FILES \
			/etc/network/interfaces /etc/network/options \
			/etc/nylon/route.list"
		[ "$DO_NYLON" == "Y" ] && FILES="$FILES /etc/nylon/"
		[ "$DO_CERTS" == "Y" ] && FILES="$FILES /etc/certs/"
	fi
	
	# no other options: default
	if [ "$FILES" == "" ]; then
		echo
		echo "default: backing up most files from /etc"
		echo
		echo "if you want to install the configuration files on a new distribution"
		echo "version, it's always better to backup less files, so please"
		echo "consider using the command line switches!"
		echo
		
		FILES="/etc"
		cat > /tmp/exclude <<EOF
init.d
terminfo
hotplug
skel
protocols
services
moduli
ssh_host_rsa_key.pub
ssh_host_dsa_key.pub
ssh_host_dsa_key
ssh_host_rsa_key
*.hex
*.pda
hotplug.d
version
.configured
ld.so.cache
kismet_drone.conf
kismet_ui.conf
ap_manuf
client_manuf
inputrc
udhcpc.d
pcmcia
if-pre-up.d
ifstate#
if-down.d
if-up.d
if-post-down.d
filesystems
modutils
rc?.d
mtab
arch.conf
rpc
README
firewall-masq
firewall-standalone
ip-up
ip-up.d
ip-down
ip-down.d
apm
modules
modules.conf
modules.conf.old
openvpn-status.log
ipp.txt
timestamp
ifplugd
logcheck
device_table
EOF
	fi

	tar cvzf $TAR_FILE $FILES --exclude=/tmp/exclude
fi
echo "done"